@@ -9,7 +9,7 @@
 **  This is part of the CTSim program
 **  Copyright (c) 1983-2001 Kevin Rosenberg
 **
-**  $Id: ctsim.cpp 7061 2003-09-07 06:34:45Z kevin $
+**  $Id$
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -69,9 +69,9 @@
 #endif
 #endif
 
-static const char* rcsindent = "$Id: ctsim.cpp 7061 2003-09-07 06:34:45Z kevin $";
+static const char* rcsindent = "$Id$";
 
-struct option CTSimApp::ctsimOptions[] = 
+struct option CTSimApp::ctsimOptions[] =
 {
   {"help", 0, 0, O_HELP},
   {"version", 0, 0, O_VERSION},
@@ -103,9 +103,9 @@ CTSimApp::OnInit()
 #ifdef HAVE_SETPRIORITY
   setpriority (PRIO_PROCESS, 0, 15);  // set to low scheduling priority
 #endif
-  
+
   openConfig();
-  
+
   g_bRunningWXWindows = true;
   bool bPrintFiles = false;
   // process options
@@ -117,7 +117,7 @@ CTSimApp::OnInit()
 #endif
     if (c == -1)
       break;
-    
+
     switch (c) {
     case O_VERSION:
       std::cout << rcsindent << std::endl;
@@ -139,9 +139,9 @@ CTSimApp::OnInit()
       exit (1);
     }
   }
-  
+
   m_docManager = new wxDocManager (wxDEFAULT_DOCMAN_FLAGS, true);
-  
+
   m_pDocTemplImage = new wxDocTemplate (m_docManager, "ImageFile", "*.if", "", "if", "ImageFile", "ImageView", CLASSINFO(ImageFileDocument), CLASSINFO(ImageFileView));
   m_pDocTemplProjection = new wxDocTemplate (m_docManager, "ProjectionFile", "*.pj", "", "pj", "ProjectionFile", "ProjectionView", CLASSINFO(ProjectionFileDocument), CLASSINFO(ProjectionFileView));
   m_pDocTemplPhantom = new wxDocTemplate (m_docManager, "PhantomFile", "*.phm", "", "phm", "PhantomFile", "PhantomView", CLASSINFO(PhantomFileDocument), CLASSINFO(PhantomFileView));
@@ -150,35 +150,35 @@ CTSimApp::OnInit()
 #if wxUSE_GLCANVAS
   m_pDocTemplGraph3d = new wxDocTemplate (m_docManager, "Graph3dFile", "*.g3d", "", "g3d", "Graph3dFile", "Graph3dView", CLASSINFO(Graph3dFileDocument), CLASSINFO(Graph3dFileView), wxTEMPLATE_INVISIBLE);
 #endif
-  
+
 #if wxUSE_GIF
   wxImage::AddHandler(new wxGIFHandler);     // Required for images in the online documentation
 #endif
-  
+
 #if wxUSE_STREAMS && wxUSE_ZIPSTREAM && wxUSE_ZLIB
   wxFileSystem::AddHandler(new wxZipFSHandler);     // Required for advanced HTML help
 #endif
-  
+
   // Create the main frame window
   int xDisplay, yDisplay;
   ::wxDisplaySize (&xDisplay, &yDisplay);
 
-  m_pFrame = new MainFrame(m_docManager, (wxFrame *) NULL, -1, "CTSim", wxPoint(0, 0), 
+  m_pFrame = new MainFrame(m_docManager, (wxFrame *) NULL, -1, "CTSim", wxPoint(0, 0),
 #ifdef CTSIM_MDI
-    wxSize(nearest<int>(xDisplay * .75), nearest<int>(yDisplay * .75)), 
+    wxSize(nearest<int>(xDisplay * .75), nearest<int>(yDisplay * .75)),
 #else
-    wxSize(nearest<int>(xDisplay * .6), nearest<int>(yDisplay * .4)), 
+    wxSize(nearest<int>(xDisplay * .6), nearest<int>(yDisplay * .4)),
 #endif
     wxDEFAULT_FRAME_STYLE);
-  
+
   setIconForFrame (m_pFrame);
   m_pFrame->Centre(wxBOTH);
-  m_pFrame->Show(true);  
+  m_pFrame->Show(true);
   SetTopWindow (m_pFrame);
-  
+
   if (m_pConfig)
     m_docManager->FileHistoryLoad(*m_pConfig);
-  
+
 #ifdef CTSIM_MDI
   m_pLogDoc = newTextDoc();
   if (m_pLogDoc) {
@@ -196,7 +196,7 @@ CTSimApp::OnInit()
     m_pLog = new wxTextCtrl (m_pFrame, -1, "Log Window\n", wxPoint(0, 0), wxSize(0,0), wxTE_MULTILINE | wxTE_READONLY);
 #endif
   wxLog::SetActiveTarget (new wxLogTextCtrl(m_pLog));
-  
+
   wxString helpDir;
   if (! m_pConfig->Read("HelpDir", &helpDir))
     helpDir = ::wxGetCwd();
@@ -212,7 +212,7 @@ CTSimApp::OnInit()
   wxString docFile = docDir + "ctsim.htb";
   if (! m_pFrame->getHtmlHelpController().AddBook(docFile) &&
     ! m_pFrame->getHtmlHelpController().AddBook("/usr/share/ctsim/ctsim.htb") &&
-	! m_pFrame->getHtmlHelpController().AddBook("/tmp/ctsim.htb"))
+        ! m_pFrame->getHtmlHelpController().AddBook("/tmp/ctsim.htb"))
         *m_pLog << "Cannot initialize the HTML Help system" << "\n";
   else {
     if (::wxDirExists ("/tmp"))
@@ -220,7 +220,7 @@ CTSimApp::OnInit()
     m_pFrame->getHtmlHelpController().UseConfig (m_pConfig);
   }
 #endif
-  
+
   for (int i = optind + 1; i <= argc; i++) {
     wxString filename = argv [i - 1];
     wxDocument* pNewDoc = m_docManager->CreateDocument (filename, wxDOC_SILENT);
@@ -242,10 +242,10 @@ CTSimApp::OnInit()
     closeEvent.SetInt (MAINMENU_FILE_EXIT);
     m_pFrame->AddPendingEvent(closeEvent);
   }
-  
+
   if (getStartupTips())
     ShowTips();
-  
+
 #ifdef HAVE_WXTHREADS
   m_pBackgroundMgr = new BackgroundManager;
 #endif
@@ -267,7 +267,7 @@ void
 CTSimApp::setIconForFrame(wxFrame* pFrame)
 {
   wxIcon iconApp (ctsim16_xpm);
-  
+
   if (iconApp.Ok())
     pFrame->SetIcon (iconApp);
 }
@@ -286,7 +286,7 @@ int
 CTSimApp::OnExit()
 {
   closeConfig();
-  
+
 #ifdef HAVE_DMALLOC
   dmalloc_shutdown();
 #endif
@@ -301,7 +301,7 @@ CTSimApp::openConfig()
 #else
   m_pConfig = new wxConfig("ctsim", "Kevin Rosenberg", ".ctsim", "", wxCONFIG_USE_LOCAL_FILE);
 #endif
-  
+
   wxConfigBase::Set(m_pConfig);
   m_pConfig->Read ("AdvancedOptions", &m_bAdvancedOptions);
   m_pConfig->Read ("SetModifyNewDocs", &m_bSetModifyNewDocs);
@@ -341,10 +341,10 @@ wxString
 CTSimApp::getUntitledFilename()
 {
   static int untitledNumber = 1;
-  
+
   wxString filename ("Untitled");
   filename << untitledNumber++;
-  
+
   return (filename);
 }
 
@@ -425,28 +425,28 @@ MainFrame::MainFrame(wxDocManager *manager, wxFrame *frame, wxWindowID id, const
 #endif
 {
   m_bShuttingDown = false;
-  
+
   //// Make a menubar
   wxMenu *file_menu = new wxMenu;
-  
+
   file_menu->Append(MAINMENU_FILE_CREATE_PHANTOM, "Cr&eate Phantom...\tCtrl-P");
   file_menu->Append(MAINMENU_FILE_CREATE_FILTER, "Create &Filter...\tCtrl-F");
   file_menu->Append(wxID_OPEN, "&Open...\tCtrl-O");
-  
+
   file_menu->AppendSeparator();
   file_menu->Append (MAINMENU_IMPORT, "&Import...\tCtrl-M");
   file_menu->Append (MAINMENU_FILE_PREFERENCES, "Prefere&nces...");
   file_menu->Append(MAINMENU_FILE_EXIT, "E&xit");
-  
+
   //  history of files visited
   theApp->getDocManager()->FileHistoryAddFilesToMenu(file_menu);
   theApp->getDocManager()->FileHistoryUseMenu(file_menu);
-  
+
 #ifndef CTSIM_MDI
   m_pWindowMenu = new wxMenu;
   m_pWindowMenu->UpdateUI (this);
 #endif
-  
+
   wxMenu* help_menu = new wxMenu;
   help_menu->Append (MAINMENU_HELP_CONTENTS, "&Contents\tF1");
   help_menu->Append (MAINMENU_HELP_TIPS, "&Tips");
@@ -455,18 +455,18 @@ MainFrame::MainFrame(wxDocManager *manager, wxFrame *frame, wxWindowID id, const
   help_menu->Append (MAINMENU_HELP_SECONDARY, "&Secondary Help");
 #endif
   help_menu->Append (MAINMENU_HELP_ABOUT, "&About");
-  
+
   wxMenuBar* menu_bar = new wxMenuBar;
-  
+
   menu_bar->Append(file_menu, "&File");
 #ifndef CTSIM_MDI
   menu_bar->Append(m_pWindowMenu, "&Window");
 #endif
   menu_bar->Append(help_menu, "&Help");
-  
+
   SetMenuBar(menu_bar);
-  
-  
+
+
 #ifndef CTSIM_MDI
   int i;
   for (i = 0; i < MAX_WINDOW_MENUITEMS; i++) {
@@ -475,7 +475,7 @@ MainFrame::MainFrame(wxDocManager *manager, wxFrame *frame, wxWindowID id, const
     m_pWindowMenu->Enable (MAINMENU_WINDOW_BASE+i, false);
   }
 #endif
-  
+
   m_iDefaultPhantomID = Phantom::PHM_HERMAN;
   m_iDefaultFilterID = SignalFilter::FILTER_BANDLIMIT;
   m_iDefaultFilterDomainID = SignalFilter::DOMAIN_FREQUENCY;
@@ -486,7 +486,7 @@ MainFrame::MainFrame(wxDocManager *manager, wxFrame *frame, wxWindowID id, const
   m_dDefaultFilterInputScale = 1.;
   m_dDefaultFilterOutputScale = 1.;
   m_iDefaultImportFormat = ImageFile::IMPORT_FORMAT_PNG;
-  
+
   wxAcceleratorEntry accelEntries[15];
   accelEntries[0].Set (wxACCEL_CTRL, static_cast<int>('O'), wxID_OPEN);
   accelEntries[1].Set (wxACCEL_CTRL, static_cast<int>('P'), MAINMENU_FILE_CREATE_PHANTOM);
@@ -500,7 +500,7 @@ MainFrame::MainFrame(wxDocManager *manager, wxFrame *frame, wxWindowID id, const
 #else
   wxAcceleratorTable accelTable (5, accelEntries);
 #endif
-  
+
   SetAcceleratorTable (accelTable);
 }
 
@@ -522,8 +522,8 @@ MainFrame::~MainFrame()
   if (theApp->getConfig())
     theApp->getDocManager()->FileHistorySave (*theApp->getConfig());
   ::wxYield();
-  delete theApp->getDocManager();	
-  
+  delete theApp->getDocManager();
+
 }
 
 void
@@ -531,14 +531,14 @@ MainFrame::OnSize (wxSizeEvent& event)
 {
 #ifdef CTSIM_MDI
   if (theApp->getLogDoc()) {
-    int xSize, ySize;	
+    int xSize, ySize;
     GetClientSize(&xSize, &ySize);
     int yLogSize = ySize / 4;
     theApp->getLogDoc()->getView()->getFrame()->SetSize (0, ySize - yLogSize, xSize, yLogSize);
     theApp->getLogDoc()->getView()->getFrame()->Show (true);
   }
 #endif
-  
+
 #if CTSIM_MDI
   wxDocMDIParentFrame::OnSize (event);
 #else
@@ -546,7 +546,7 @@ MainFrame::OnSize (wxSizeEvent& event)
 #endif
 }
 
-void 
+void
 MainFrame::OnCreatePhantom(wxCommandEvent& event)
 {
   DialogGetPhantom dialogPhantom (this, m_iDefaultPhantomID);
@@ -559,10 +559,10 @@ MainFrame::OnCreatePhantom(wxCommandEvent& event)
     m_iDefaultPhantomID = Phantom::convertNameToPhantomID (selection.c_str());
     theApp->getDocManager()->CreateDocument (filename, wxDOC_SILENT);
   }
-  
+
 }
 
-void 
+void
 MainFrame::OnCreateFilter (wxCommandEvent& WXUNUSED(event))
 {
   DialogGetFilterParameters dialogFilter (this, m_iDefaultFilterXSize, m_iDefaultFilterYSize, m_iDefaultFilterID, m_dDefaultFilterParam, m_dDefaultFilterBandwidth, m_iDefaultFilterDomainID, m_dDefaultFilterInputScale, m_dDefaultFilterOutputScale);
@@ -579,9 +579,9 @@ MainFrame::OnCreateFilter (wxCommandEvent& WXUNUSED(event))
     m_dDefaultFilterInputScale = dialogFilter.getInputScale();
     m_dDefaultFilterOutputScale = dialogFilter.getOutputScale();
     std::ostringstream os;
-    os << "Generate Filter=" << strFilter.c_str() 
-      << ", size=(" << static_cast<int>(m_iDefaultFilterXSize) << "," << static_cast<int>(m_iDefaultFilterYSize) 
-      << "), domain=" << strDomain.c_str() << ", filterParam=" << m_dDefaultFilterParam << ", bandwidth=" << m_dDefaultFilterBandwidth 
+    os << "Generate Filter=" << strFilter.c_str()
+      << ", size=(" << static_cast<int>(m_iDefaultFilterXSize) << "," << static_cast<int>(m_iDefaultFilterYSize)
+      << "), domain=" << strDomain.c_str() << ", filterParam=" << m_dDefaultFilterParam << ", bandwidth=" << m_dDefaultFilterBandwidth
       << ", inputScale=" << m_dDefaultFilterInputScale << ", outputScale=" << m_dDefaultFilterOutputScale;
     *theApp->getLog() << os.str().c_str() << "\n";
     wxString filename = "untitled.if";
@@ -632,7 +632,7 @@ MainFrame::OnNewImageFile (wxCommandEvent& event)
   if (! pImageDoc) {
     sys_error (ERR_SEVERE, "Unable to create image file");
     return;
-  }  
+  }
   pImageDoc->setImageFile (pImageFile);
   if (theApp->getAskDeleteNewDocs())
     pImageDoc->Modify (true);
@@ -646,7 +646,7 @@ MainFrame::OnNewProjectionFile (wxCommandEvent& event)
   if (! pProjDoc) {
     sys_error (ERR_SEVERE, "Unable to create projection file");
     return;
-  }  
+  }
   pProjDoc->setProjections (pProjections);
   if (theApp->getAskDeleteNewDocs())
     pProjDoc->Modify (true);
@@ -664,13 +664,13 @@ MainFrame::OnHelpTips (wxCommandEvent& event)
   theApp->ShowTips();
 }
 
-void 
+void
 MainFrame::OnHelpContents (wxCommandEvent& event)
 {
   showHelp (event.GetId());
 }
 
-void 
+void
 MainFrame::OnHelpButton (wxCommandEvent& event)
 {
   showHelp (event.GetId());
@@ -688,7 +688,7 @@ void
 MainFrame::showHelp (int commandID)
 {
   switch (commandID) {
-    
+
   case MAINMENU_HELP_CONTENTS:
 #ifdef CTSIM_WINHELP
     m_winHelp.DisplayContents ();
@@ -696,7 +696,7 @@ MainFrame::showHelp (int commandID)
     m_htmlHelp.Display ("Contents");
 #endif
     break;
-        
+
   default:
 #ifdef CTSIM_WINHELP
     m_winHelp.DisplaySection (commandID);
@@ -707,7 +707,7 @@ MainFrame::showHelp (int commandID)
   }
 }
 
-void 
+void
 MainFrame::OnExit (wxCommandEvent& WXUNUSED(event) )
 {
   Close(true);
@@ -738,11 +738,11 @@ MainFrame::OnUpdateUI (wxUpdateUIEvent& rEvent)
     static_cast<wxMenuItemBase*>(m_apWindowMenuItems[i])->SetName (wxString("[EMPTY]"));
     m_apWindowMenuData[i] = NULL;
   }
-#endif	
+#endif
 }
 
 
-void 
+void
 MainFrame::DoWindowMenu (int iMenuPosition, wxCommandEvent& event)
 {
   if (wxDocument* pDoc = m_apWindowMenuData [iMenuPosition]) {
@@ -819,11 +819,11 @@ void MainFrame::OnWindowMenu19 (wxCommandEvent& event)
 
 class BitmapControl : public wxPanel
 {
-private:  
+private:
   DECLARE_DYNAMIC_CLASS (BitmapControl)
     DECLARE_EVENT_TABLE ()
     wxBitmap* m_pBitmap;
-  
+
 public:
   BitmapControl (wxBitmap* pBitmap, wxWindow *parent, wxWindowID id = -1,
     const wxPoint& pos = wxDefaultPosition,
@@ -831,15 +831,15 @@ public:
     long style = wxSTATIC_BORDER,
     const wxValidator& validator = wxDefaultValidator,
     const wxString& name = "BitmapCtrl");
-  
-  
+
+
   virtual ~BitmapControl();
-  
+
   virtual wxSize GetBestSize() const;
-  
-  wxBitmap* getBitmap() 
+
+  wxBitmap* getBitmap()
   { return m_pBitmap; }
-  
+
   void OnPaint(wxPaintEvent& event);
 };
 
@@ -851,12 +851,12 @@ END_EVENT_TABLE()
 IMPLEMENT_CLASS(BitmapControl, wxPanel)
 
 
-BitmapControl::BitmapControl (wxBitmap* pBitmap, wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, 
+BitmapControl::BitmapControl (wxBitmap* pBitmap, wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size,
                               long style, const wxValidator& validator, const wxString& name)
                               : m_pBitmap(pBitmap)
 {
   Create(parent, id, pos, size, style, name);
-  
+
   SetSize (GetBestSize());
 }
 
@@ -884,7 +884,7 @@ BitmapControl::OnPaint (wxPaintEvent& event)
 class BitmapDialog : public wxDialog {
 private:
   BitmapControl* m_pBitmapCtrl;
-  
+
 public:
   BitmapDialog (wxBitmap* pBitmap, char const* pszTitle);
   virtual ~BitmapDialog();
@@ -894,15 +894,15 @@ BitmapDialog::BitmapDialog (wxBitmap* pBitmap, char const* pszTitle)
 : wxDialog(theApp->getMainFrame(), -1, wxString(pszTitle), wxDefaultPosition, wxDefaultSize, wxDIALOG_MODAL | wxDEFAULT_DIALOG_STYLE)
 {
   wxBoxSizer* pTopSizer = new wxBoxSizer (wxVERTICAL);
-  
+
   pTopSizer->Add (new BitmapControl (pBitmap, this), 0, wxALIGN_CENTER | wxALL, 5);
-  
+
   wxBoxSizer* pButtonSizer = new wxBoxSizer (wxHORIZONTAL);
   wxButton* pButtonOk = new wxButton (this, wxID_OK, "Ok");
   pButtonSizer->Add (pButtonOk, 0, wxEXPAND | wxALL, 10);
-  
+
   pTopSizer->Add (pButtonSizer, 0, wxALIGN_CENTER);
-  
+
   SetAutoLayout (true);
   SetSizer (pTopSizer);
   pTopSizer->Fit (this);
@@ -913,11 +913,11 @@ BitmapDialog::~BitmapDialog()
 {}
 
 
-void 
+void
 MainFrame::OnPreferences (wxCommandEvent& WXUNUSED(event) )
 {
-  DialogPreferences dlg (this, "CTSim Preferences", theApp->getAdvancedOptions(), 
-    theApp->getAskDeleteNewDocs(), theApp->getVerboseLogging(), theApp->getStartupTips(), 
+  DialogPreferences dlg (this, "CTSim Preferences", theApp->getAdvancedOptions(),
+    theApp->getAskDeleteNewDocs(), theApp->getVerboseLogging(), theApp->getStartupTips(),
     theApp->getUseBackgroundTasks());
   if (dlg.ShowModal() == wxID_OK) {
     theApp->setAdvancedOptions (dlg.getAdvancedOptions());
@@ -928,16 +928,16 @@ MainFrame::OnPreferences (wxCommandEvent& WXUNUSED(event) )
   }
 }
 
-void 
+void
 MainFrame::OnImport (wxCommandEvent& WXUNUSED(event) )
 {
   DialogImportParameters dialogImport (this, m_iDefaultImportFormat);
   if (dialogImport.ShowModal() != wxID_OK)
     return;
-  
+
   wxString strFormatName (dialogImport.getFormatName ());
   m_iDefaultImportFormat = ImageFile::convertImportFormatNameToID (strFormatName.c_str());
-  
+
   wxString strExt;
   wxString strWildcard;
   if (m_iDefaultImportFormat == ImageFile::IMPORT_FORMAT_PPM) {
@@ -959,8 +959,8 @@ MainFrame::OnImport (wxCommandEvent& WXUNUSED(event) )
   else {
     return;
   }
-  
-  wxString strFilename = wxFileSelector (wxString("Import Filename"), wxString(""), 
+
+  wxString strFilename = wxFileSelector (wxString("Import Filename"), wxString(""),
     wxString(""), strExt, strWildcard, wxHIDE_READONLY | wxOPEN);
   if (! strFilename.IsEmpty()) {
     if (m_iDefaultImportFormat == ImageFile::IMPORT_FORMAT_PPM || m_iDefaultImportFormat == ImageFile::IMPORT_FORMAT_PNG) {
@@ -979,7 +979,7 @@ MainFrame::OnImport (wxCommandEvent& WXUNUSED(event) )
         pIFDoc->getView()->getFrame()->Show(true);
       } else
         delete pIF;
-    } 
+    }
 #ifdef HAVE_CTN_DICOM
     else if (m_iDefaultImportFormat == ImageFile::IMPORT_FORMAT_DICOM) {
       DicomImporter dicomImport (strFilename.c_str());
@@ -996,7 +996,7 @@ MainFrame::OnImport (wxCommandEvent& WXUNUSED(event) )
           pIFDoc->Modify (true);
         pIFDoc->UpdateAllViews();
         pIFDoc->getView()->setInitialClientSize();
-	pIFDoc->Activate();
+        pIFDoc->Activate();
       } else if (dicomImport.testProjections()) {
         ProjectionFileDocument* pProjDoc = theApp->newProjectionDoc();
         Projections* pProj = dicomImport.getProjections();
@@ -1009,10 +1009,10 @@ MainFrame::OnImport (wxCommandEvent& WXUNUSED(event) )
           pProjDoc->Modify (true);
         pProjDoc->UpdateAllViews();
         pProjDoc->getView()->setInitialClientSize();
-	pProjDoc->Activate();
+        pProjDoc->Activate();
       } else
         ::wxMessageBox ("Unrecognized DICOM file contents", "Import Error");
-    } 
+    }
 #endif
     else
       sys_error (ERR_WARNING, "Unknown import format type");
@@ -1020,7 +1020,7 @@ MainFrame::OnImport (wxCommandEvent& WXUNUSED(event) )
 }
 
 #include "./splash.xpm"
-void 
+void
 MainFrame::OnAbout(wxCommandEvent& WXUNUSED(event) )
 {
   wxString strOSDesc = ::wxGetOsDescription();
@@ -1040,7 +1040,7 @@ MainFrame::OnAbout(wxCommandEvent& WXUNUSED(event) )
     *theApp->getLog() << " " <<  CTSIMVERSION;
 #endif
   *theApp->getLog() << "\n";
-  
+
   wxBitmap bmp (splash);
   if (bmp.Ok()) {
     BitmapDialog dlg (&bmp, "About CTSim");
@@ -1053,7 +1053,7 @@ MainFrame::OnAbout(wxCommandEvent& WXUNUSED(event) )
     msg << "Version: " <<  CTSIMVERSION << "\n\n";
 #endif
     msg += "Author: Kevin Rosenberg <kevin@rosenberg.net>\nUsage: ctsim [files-to-open..] [--help]";
-    
+
     wxMessageBox(msg, "About CTSim", wxOK | wxICON_INFORMATION, this);
     *theApp->getLog() << msg << "\n";
   }
@@ -1097,7 +1097,7 @@ CTSimApp::newPlotDoc()
     newDoc->SetDocumentTemplate (m_pDocTemplPlot);
     newDoc->OnNewDocument();
   }
-  
+
   return newDoc;
 }
 
@@ -1107,14 +1107,14 @@ CTSimApp::newTextDoc()
 {
   wxString strFilename (getUntitledFilename());
   strFilename += ".txt";
-  
+
   TextFileDocument* newDoc = dynamic_cast<TextFileDocument*>(m_pDocTemplText->CreateDocument (""));
   if (newDoc) {
     newDoc->SetDocumentName (m_pDocTemplText->GetDocumentName());
     newDoc->SetDocumentTemplate (m_pDocTemplText);
     newDoc->OnNewDocument();
   }
-  
+
   return newDoc;
 }
 
@@ -1128,7 +1128,7 @@ CTSimApp::newPhantomDoc()
     newDoc->SetDocumentTemplate (m_pDocTemplPhantom);
     newDoc->OnNewDocument();
   }
-  
+
   return newDoc;
 }
 
@@ -1143,7 +1143,7 @@ CTSimApp::newGraph3dDoc()
     newDoc->SetDocumentTemplate (m_pDocTemplGraph3d);
     newDoc->OnNewDocument();
   }
-  
+
   return newDoc;
 }
 #endif
